# pymmcore-nano

Experimental python bindings for CMMCore using nanobind.

### Setup

```sh
git clone https://github.com/pymmcore-plus/pymmcore-nano.git
git submodule update --init
```

make sure you have uv installed, if not: <https://docs.astral.sh/uv/getting-started/installation/>

### create environment and install in editable mode

```sh
make install
```

### test

```sh
make test
```
